/*
 * Mailbox folder access
 *
 * Copyright (C) 2013  Enrico Zini <enrico@debian.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#include "config.h"
#include <buffy/utils/system.h>
#include <tests/test-utils.h>
#include <sys/stat.h>

namespace tut {
using namespace buffy;
using namespace wibble::tests;

struct buffy_utils_system_shar {
	buffy_utils_system_shar() {
	}
	~buffy_utils_system_shar() {
	}
};
TESTGRP(buffy_utils_system);

// Make sure that we are built with largefile support, so that we agree with
// libwibble
template<> template<>
void to::test<1>()
{
    wassert(actual(sizeof(off_t)) == 8);
}

}

// vim:set ts=4 sw=4:
